pub struct CreateReport {
pub manifest: Manifest,
pub out_path: PathBuf,
pub compressed_bytes: u64,
pub dry_run: bool,
}Expand description
What create produced.
Fields
manifest: ManifestManifest embedded in the archive (or that would have been, on a dry run).
out_path: PathBufPath of the written archive, or where one would have been written.
compressed_bytes: u64Size of the archive on disk, after compression. 0 on a dry run.
dry_run: boolWhether this was a dry run, in which case nothing was written.